@@ -5,7 +5,7 @@ from facadedevice import Facade
 
 class On(Facade):
     def safe_init_device(self):
-        super(On, self).safe_init_device()
+        super().safe_init_device()
         self.set_state(DevState.ON)
 
 
